CafSdk class

Constructors

CafSdk()

Properties

eventStream Stream
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initializeCafSdk({required CafSdkConfiguration cafSdkConfiguration, CafDocumentDetectorConfiguration? documentDetectorConfiguration, CafDocumentDetectorUIConfiguration? documentDetectorUIConfiguration, CafFaceLivenessConfiguration? faceLivenessConfiguration, CafFaceLivenessUIConfiguration? faceLivenessUIConfiguration}) Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited