MethodChannelCafSdk class

An implementation of CafSdkPlatform that uses method channels.

Inheritance

Constructors

MethodChannelCafSdk()

Properties

eventStream Stream<CafResponse>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyCafDocumentDetector(CafDocumentDetectorConfiguration documentDetectorConfiguration) Future<bool>
override
applyCafDocumentDetectorUI(CafDocumentDetectorUIConfiguration documentDetectorUIConfiguration) Future<bool>
override
applyCafFaceLiveness(CafFaceLivenessConfiguration faceLivenessConfiguration) Future<bool>
override
applyCafFaceLivenessUI(CafFaceLivenessUIConfiguration faceLivenessUIConfiguration) Future<bool>
override
initializeCafSdk({required CafSdkConfiguration cafSdkConfiguration, CafDocumentDetectorConfiguration? documentDetectorConfiguration, CafDocumentDetectorUIConfiguration? documentDetectorUIConfiguration, CafFaceLivenessConfiguration? faceLivenessConfiguration, CafFaceLivenessUIConfiguration? faceLivenessUIConfiguration}) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCafSdk() Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited