CafSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CafSdkPlatform
Implementers

Constructors

CafSdkPlatform()
Constructs a CafSdkPlatform.

Properties

eventStream → Stream<CafResponse>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyCafDocumentDetector(CafDocumentDetectorConfiguration documentDetectorConfiguration) → Future<bool>
applyCafDocumentDetectorUI(CafDocumentDetectorUIConfiguration documentDetectorUIConfiguration) → Future<bool>
applyCafFaceLiveness(CafFaceLivenessConfiguration faceLivenessConfiguration) → Future<bool>
applyCafFaceLivenessUI(CafFaceLivenessUIConfiguration faceLivenessUIConfiguration) → Future<bool>
initializeCafSdk({required CafSdkConfiguration cafSdkConfiguration, CafDocumentDetectorConfiguration? documentDetectorConfiguration, CafDocumentDetectorUIConfiguration? documentDetectorUIConfiguration, CafFaceLivenessConfiguration? faceLivenessConfiguration, CafFaceLivenessUIConfiguration? faceLivenessUIConfiguration}) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCafSdk() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CafSdkPlatform
The default instance of CafSdkPlatform to use.
getter/setter pair