CafFileFormat enum

Supported file formats for document uploads.

Inheritance
Available extensions

Values

png → const CafFileFormat
const CafFileFormat('PNG')
jpg → const CafFileFormat
const CafFileFormat('JPG')
jpeg → const CafFileFormat
const CafFileFormat('JPEG')
pdf → const CafFileFormat
const CafFileFormat('PDF')
heif → const CafFileFormat
const CafFileFormat('HEIF')
heic → const CafFileFormat
const CafFileFormat('HEIC')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) CafFileFormat

Constants

values → const List<CafFileFormat>
A constant List of the values in this enum, in order of their declaration.