CafSuccessResponse class

Represents a successful response for any Caf module.

Constructors

CafSuccessResponse({required CafModuleType moduleName, required String? signedResponse})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
moduleName CafModuleType
The module identifier that produced this result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signedResponse String?
Signed response string returned by the module service.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited