CafResponse class
Constructors
- CafResponse({bool cancelled = false, bool loading = false, bool loaded = false, CafErrorResponse? error, CafSuccessResponse? success, CafFailureResponse? failure, CafLog? log})
-
const
- CafResponse.fromEvent(Map event)
-
factory
Properties
- cancelled → bool
-
True when the user has cancelled the operation.
final
- error → CafErrorResponse?
-
Populated on error; null otherwise.
final
- failure → CafFailureResponse?
-
Populated on soft failure; null otherwise.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loaded → bool
-
True when a preloaded session is ready.
final
- loading → bool
-
True while a module capture operation is in progress.
final
- log → CafLog?
-
Populated when a log message is emitted; null otherwise.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → CafSuccessResponse?
-
Populated on success; null otherwise.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited